summaryrefslogtreecommitdiff
path: root/drivers/hwmon
diff options
context:
space:
mode:
authorLaxman Dewangan <ldewangan@nvidia.com>2013-02-01 16:27:16 +0530
committerMandar Padmawar <mpadmawar@nvidia.com>2013-02-05 07:01:17 -0800
commite4dfec6608d4ec01de81a080a1cff491c3960761 (patch)
tree8cc2fa63d769e6769515629d49a9ce11a9119cf4 /drivers/hwmon
parentfea89035708cc9f21f995194cb1586672e9c0e05 (diff)
hwmon: ina230: add support for HPA02149
The TI current/power monitor device INA230 is compatible with the HAP02149. Add module ID for the HPA02149. This device is also compatible with INA226 and hence adding ina226 as module-id. In this way, this driver can regsitered with the name as "ina226" or "ina230" or "hpa02149". bug 1218687 Change-Id: Ic67227bc6d415fd559d804f4bd97e4ea4018d872 Signed-off-by: Laxman Dewangan <ldewangan@nvidia.com> Reviewed-on: http://git-master/r/196411
Diffstat (limited to 'drivers/hwmon')
-rw-r--r--drivers/hwmon/Kconfig5
-rw-r--r--drivers/hwmon/ina230.c7
2 files changed, 6 insertions, 6 deletions
diff --git a/drivers/hwmon/Kconfig b/drivers/hwmon/Kconfig
index 41ea438fb577..e589e4da73f4 100644
--- a/drivers/hwmon/Kconfig
+++ b/drivers/hwmon/Kconfig
@@ -1402,11 +1402,10 @@ config SENSORS_INA219
Support for the TI INA219 power monitor sensor.
config SENSORS_INA230
- tristate "Texas Instruments INA230 POWER MONITOR SENSOR DRIVER"
+ tristate "TI INA230/INA226/HPA02149 POWER MONITOR SENSOR DRIVER"
depends on I2C
help
- Support for the TI INA230 power monitor sensor.
- (also works for TI INA226)
+ Support for the TI INA230/INA226/HPA02149 power monitor sensor.
config SENSORS_INA3221
tristate "Texas Instruments INA3221 POWER MONITOR SENSOR DRIVER"
diff --git a/drivers/hwmon/ina230.c b/drivers/hwmon/ina230.c
index 857cb6c4599f..5abf9d1e1c7e 100644
--- a/drivers/hwmon/ina230.c
+++ b/drivers/hwmon/ina230.c
@@ -1,6 +1,5 @@
/*
* ina230.c - driver for TI INA230 current / power monitor sensor
* (also compatible with TI INA226)
*
*
* Copyright (c) 2011, NVIDIA Corporation.
@@ -598,7 +597,9 @@ static int ina230_resume(struct i2c_client *client)
static const struct i2c_device_id ina230_id[] = {
- {DRIVER_NAME, 0 },
+ {"ina226", 0 },
+ {"ina230", 0 },
+ {"hpa02149", 0 },
{}
};
MODULE_DEVICE_TABLE(i2c, ina230_id);
@@ -1,6 +1,5 @@
/*
- * ina230.c - driver for TI INA230 current / power monitor sensor
- * (also compatible with TI INA226)
+ * ina230.c - driver for TI INA230/INA226/HPA02149 current/power monitor sensor
*
*